pub struct BuildArgs {
pub build_system: Option<BuildSystem>,
pub language: Option<TargetLanguage>,
pub platform: Option<Platform>,
pub lfc: Option<PathBuf>,
pub no_compile: bool,
pub keep_going: bool,
pub release: bool,
pub apps: Vec<String>,
pub threads: usize,
}Fields
build_system: Option<BuildSystem>Which build system to use
language: Option<TargetLanguage>Which target to build
platform: Option<Platform>Overwrites any possible board definition in Lingo.toml
lfc: Option<PathBuf>Tell lingo where the lfc toolchain can be found
no_compile: boolSkips building aka invoking the build system so it only generates code
keep_going: boolIf one of the apps fails to build dont interrupt the build process
release: boolCompiles the binaries with optimizations turned on and strips debug symbols
apps: Vec<String>List of apps to build if left empty all apps are built
threads: usizeNumber of threads to use for parallel builds. Zero means it will be determined automatically.
Implementations
Sourceimpl BuildArgs
impl BuildArgs
pub fn build_profile(&self) -> BuildProfile