pub struct BuildCommandOptions {
pub profile: BuildProfile,
pub compile_target_code: bool,
pub lfc_exec_path: PathBuf,
pub max_threads: usize,
pub keep_going: bool,
}Fields
profile: BuildProfileBuild profile, mostly relevant for target compilation.
compile_target_code: boolWhether to compile the target code.
lfc_exec_path: PathBufPath to the LFC executable.
max_threads: usizeMax threads to use for compilation. A value of zero means that the number will be automatically determined. A value of one effectively disables parallel builds.
keep_going: boolif compilation should continue if one of the apps fails building