pub enum WhichError {
CannotFindBinaryPath,
CannotGetCurrentDirAndPathListEmpty,
CannotCanonicalize,
}Variants
CannotFindBinaryPath
An executable binary with that name was not found
CannotGetCurrentDirAndPathListEmpty
There was nowhere to search and the provided name wasn’t an absolute path
CannotCanonicalize
Failed to canonicalize the path found