pub struct PackageLockSource {
pub source_type: PackageLockSourceType,
pub uri: String,
pub rev: Option<String>,
}Expand description
Struct that saves the source uri string
Fields
source_type: PackageLockSourceTypeuri: Stringrev: Option<String>Trait Implementations
Sourceimpl Debug for PackageLockSource
impl Debug for PackageLockSource
Sourceimpl<'de> Deserialize<'de> for PackageLockSource
impl<'de> Deserialize<'de> for PackageLockSource
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromStr for PackageLockSource
Parses the whole source uri string of a package
the uri string follows the pattern +(#)
impl FromStr for PackageLockSource
Parses the whole source uri string of a package
the uri string follows the pattern
Sourceimpl Serialize for PackageLockSource
impl Serialize for PackageLockSource
Sourceimpl TryFrom<&PackageLockSource> for PackageDetails
impl TryFrom<&PackageLockSource> for PackageDetails
Sourcetype Error = ParseError
type Error = ParseError
The type returned in the event of a conversion error.